summaryrefslogtreecommitdiff
path: root/src/fe-text/mainwindows.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/fe-text/mainwindows.h')
-rw-r--r--src/fe-text/mainwindows.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/src/fe-text/mainwindows.h b/src/fe-text/mainwindows.h
index 6306758f..1bca333d 100644
--- a/src/fe-text/mainwindows.h
+++ b/src/fe-text/mainwindows.h
@@ -23,8 +23,8 @@ typedef struct {
int statusbar_lines_bottom;
int statusbar_lines; /* top+bottom */
- int resize_freeze_counter;
- unsigned int resize_needed:1; /* We'll need to resize the window, but haven't got around doing it just yet. */
+ unsigned int dirty:1; /* This window needs a redraw */
+ unsigned int size_dirty:1; /* We'll need to resize the window, but haven't got around doing it just yet. */
} MAIN_WINDOW_REC;
extern GSList *mainwindows;
@@ -53,8 +53,7 @@ void mainwindow_change_active(MAIN_WINDOW_REC *mainwin,
int mainwindows_reserve_lines(int top, int bottom);
int mainwindow_set_statusbar_lines(MAIN_WINDOW_REC *window,
int top, int bottom);
-void mainwindow_resize_freeze(MAIN_WINDOW_REC *window);
-void mainwindow_resize_thaw(MAIN_WINDOW_REC *window);
+void mainwindows_redraw_dirty(void);
GSList *mainwindows_get_sorted(int reverse);